{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "samtools",
                "view"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": "BAM file",
                    "id": "#calculate_readnum.cwl/bamFile"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "default": true,
                    "label": "Print only the count",
                    "id": "#calculate_readnum.cwl/countFlag"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-F"
                    },
                    "default": 4,
                    "label": "Flag to count only the mapped reads",
                    "id": "#calculate_readnum.cwl/readFlag"
                }
            ],
            "stdout": "$(inputs.bamFile.nameroot).readnum",
            "doc": "returns the number of reads inside a *.readnum file",
            "id": "#calculate_readnum.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bamFile.nameroot).readnum"
                    },
                    "id": "#calculate_readnum.cwl/readnum"
                }
            ]
        },
        {
            "doc": "This tool wraps compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.pl,\nwhich merges neighboring or overlapping regions in a BED file.\n  Usage:   perl compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat.pl <in.bed> <out.compressed.bed>\n",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 16,
                    "ramMin": 16000
                }
            ],
            "baseCommand": [
                "compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.pl"
            ],
            "arguments": [
                "$(inputs.input_full.nameroot).compressed.bed",
                "$(inputs.input_full.nameroot).compressed.bed.full"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl/input_full"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_full.nameroot).compressed.bed"
                    },
                    "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl/output_bed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_full.nameroot).compressed.bed.full"
                    },
                    "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl/output_full"
                }
            ],
            "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl"
        },
        {
            "doc": "Returns string expression based on file contents.\n",
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#file2int.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "int",
                    "id": "#file2int.cwl/output"
                }
            ],
            "expression": "${return {'output':parseInt(inputs.file.contents)}; }",
            "id": "#file2int.cwl"
        },
        {
            "doc": "Converts a full file into a bed6 formatted file.\n",
            "class": "CommandLineTool",
            "baseCommand": [
                "full_to_bed.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--input"
                    },
                    "id": "#full_to_bed.cwl/full"
                }
            ],
            "arguments": [
                "--output",
                "$(inputs.full.nameroot).bed"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.full.nameroot).bed"
                    },
                    "id": "#full_to_bed.cwl/bed"
                }
            ],
            "id": "#full_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "get_reproducing_peaks.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 9
                    },
                    "id": "#get_reproducing_peaks.cwl/idr_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#get_reproducing_peaks.cwl/output_bed"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#get_reproducing_peaks.cwl/output_custombed"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#get_reproducing_peaks.cwl/rep1_entropy_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#get_reproducing_peaks.cwl/rep1_full_in"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#get_reproducing_peaks.cwl/rep1_full_output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#get_reproducing_peaks.cwl/rep2_entropy_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#get_reproducing_peaks.cwl/rep2_full_in"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#get_reproducing_peaks.cwl/rep2_full_output"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_bed)"
                    },
                    "id": "#get_reproducing_peaks.cwl/output_bed_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_custombed)"
                    },
                    "id": "#get_reproducing_peaks.cwl/output_custombed_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.rep1_full_output)"
                    },
                    "id": "#get_reproducing_peaks.cwl/rep1_full_output_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.rep2_full_output)"
                    },
                    "id": "#get_reproducing_peaks.cwl/rep2_full_output_file"
                }
            ],
            "id": "#get_reproducing_peaks.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "idr"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--input-file-type"
                    },
                    "default": "bed",
                    "id": "#idr.cwl/inputFileType"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-o"
                    },
                    "id": "#idr.cwl/outputFilename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--peak-merge-method"
                    },
                    "default": "max",
                    "id": "#idr.cwl/peakMergeMethod"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--plot"
                    },
                    "default": true,
                    "id": "#idr.cwl/plot"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--rank"
                    },
                    "default": 5,
                    "id": "#idr.cwl/rank"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--samples"
                    },
                    "id": "#idr.cwl/samples"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputFilename)"
                    },
                    "id": "#idr.cwl/output"
                }
            ],
            "id": "#idr.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "linescount.sh"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#linescount.cwl/textfile"
                }
            ],
            "stdout": "$(inputs.textfile.basename).linescount",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.textfile.basename).linescount"
                    },
                    "id": "#linescount.cwl/linescount"
                }
            ],
            "id": "#linescount.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 16,
                    "ramMin": 16000
                }
            ],
            "baseCommand": [
                "make_informationcontent_from_peaks.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/clip_read_num"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/compressed_bed_full"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/input_read_num"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 5,
                        "valueFrom": "${\n  if (inputs.output_excess_reads == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.excessreads\";\n  }\n  else {\n    return inputs.output_excess_reads;\n  }\n}\n"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/output_excess_reads"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 4,
                        "valueFrom": "${\n  if (inputs.output_file == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.full\";\n  }\n  else {\n    return inputs.output_file;\n  }\n}\n"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/output_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_excess_reads == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.excessreads\";\n  }\n  else {\n    return inputs.output_excess_reads;\n  }\n}"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/entropy_excess_reads"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_file == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.full\";\n  }\n  else {\n    return inputs.output_file;\n  }\n}\n"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/entropy_full"
                }
            ],
            "id": "#make_informationcontent_from_peaks.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 16,
                    "ramMin": 16000
                }
            ],
            "baseCommand": [
                "overlap_peakfi_with_bam_PE.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -5
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/clipBamFile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/clipReadnum"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputBamFile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputReadnum"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 0,
                        "valueFrom": "${\n  if (inputs.outputFile == \"\") {\n    return inputs.peakFile.nameroot + \".normed.bed\";\n  }\n  else {\n    return inputs.outputFile;\n  }\n}\n"
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/outputFile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -3
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/peakFile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outputFile == \"\") {\n    return inputs.peakFile.nameroot + \".normed.bed\";\n  }\n  else {\n    return inputs.outputFile;\n  }\n}\n"
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputNormedBed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outputFile == \"\") {\n    return inputs.peakFile.nameroot + \".normed.bed.full\";\n  }\n  else {\n    return inputs.outputFile;\n  }\n}\n"
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputNormedBedFull"
                }
            ],
            "doc": "This tool wraps\n  Usage:",
            "id": "#overlap_peakfi_with_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "parse_idr_peaks.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#parse_idr_peaks.cwl/entropyFile1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#parse_idr_peaks.cwl/entropyFile2"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#parse_idr_peaks.cwl/idrFile"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#parse_idr_peaks.cwl/outputFilename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputFilename)"
                    },
                    "id": "#parse_idr_peaks.cwl/output"
                }
            ],
            "doc": "returns the",
            "id": "#parse_idr_peaks.cwl"
        },
        {
            "doc": "The main workflow that produces two reproducible peaks via IDR given\ntwo eCLIP samples (1 input, 1 IP each).\n",
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/merged_peaks_bed"
                },
                {
                    "type": "string",
                    "id": "#main/merged_peaks_custombed"
                },
                {
                    "type": "File",
                    "id": "#main/rep1_clip_bam_file"
                },
                {
                    "type": "File",
                    "id": "#main/rep1_input_bam_file"
                },
                {
                    "type": "File",
                    "id": "#main/rep1_peaks_bed_file"
                },
                {
                    "type": "File",
                    "id": "#main/rep2_clip_bam_file"
                },
                {
                    "type": "File",
                    "id": "#main/rep2_input_bam_file"
                },
                {
                    "type": "File",
                    "id": "#main/rep2_peaks_bed_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/idr/output",
                    "id": "#main/idr_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/create_bed_from_idr/output",
                    "id": "#main/idr_output_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/get_reproducing_peaks/output_bed_file",
                    "id": "#main/merged_peaks_bed_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/get_reproducing_peaks/output_custombed_file",
                    "id": "#main/merged_peaks_custombed_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep1_input_norm_and_entropy/clip_read_num",
                    "id": "#main/rep1_clip_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep1_input_norm_and_entropy/entropy_bed",
                    "id": "#main/rep1_entropy_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep1_input_norm_and_entropy/entropy_excess_reads",
                    "id": "#main/rep1_entropy_excess_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep1_input_norm_and_entropy/entropy_full",
                    "id": "#main/rep1_entropy_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep1_input_norm_using_idr_peaks/inputNormedBed",
                    "id": "#main/rep1_idr_output_input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep1_input_norm_using_idr_peaks/inputNormedBedFull",
                    "id": "#main/rep1_idr_output_input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep1_input_norm_and_entropy/input_normed_bed",
                    "id": "#main/rep1_input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep1_input_norm_and_entropy/input_normed_full",
                    "id": "#main/rep1_input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep1_input_norm_and_entropy/input_read_num",
                    "id": "#main/rep1_input_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#main/get_reproducing_peaks/rep1_full_output_file",
                    "id": "#main/rep1_reproducing_peaks_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep2_input_norm_and_entropy/clip_read_num",
                    "id": "#main/rep2_clip_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep2_input_norm_and_entropy/entropy_bed",
                    "id": "#main/rep2_entropy_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep2_input_norm_and_entropy/entropy_excess_reads",
                    "id": "#main/rep2_entropy_excess_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep2_input_norm_and_entropy/entropy_full",
                    "id": "#main/rep2_entropy_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep2_input_norm_using_idr_peaks/inputNormedBed",
                    "id": "#main/rep2_idr_output_input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep2_input_norm_using_idr_peaks/inputNormedBedFull",
                    "id": "#main/rep2_idr_output_input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep2_input_norm_and_entropy/input_normed_bed",
                    "id": "#main/rep2_input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep2_input_norm_and_entropy/input_normed_full",
                    "id": "#main/rep2_input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/rep2_input_norm_and_entropy/input_read_num",
                    "id": "#main/rep2_input_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#main/get_reproducing_peaks/rep2_full_output_file",
                    "id": "#main/rep2_reproducing_peaks_full"
                },
                {
                    "type": "int",
                    "outputSource": "#main/reproducible_peaks_file_to_int/output",
                    "id": "#main/reproducing_peaks_count"
                }
            ],
            "steps": [
                {
                    "run": "#linescount.cwl",
                    "in": [
                        {
                            "source": "#main/get_reproducing_peaks/output_bed_file",
                            "id": "#main/count_reproducing_peaks/textfile"
                        }
                    ],
                    "out": [
                        "#main/count_reproducing_peaks/linescount"
                    ],
                    "id": "#main/count_reproducing_peaks"
                },
                {
                    "run": "#parse_idr_peaks.cwl",
                    "in": [
                        {
                            "source": "#main/rep1_input_norm_and_entropy/entropy_full",
                            "id": "#main/create_bed_from_idr/entropyFile1"
                        },
                        {
                            "source": "#main/rep2_input_norm_and_entropy/entropy_full",
                            "id": "#main/create_bed_from_idr/entropyFile2"
                        },
                        {
                            "source": "#main/idr/output",
                            "id": "#main/create_bed_from_idr/idrFile"
                        },
                        {
                            "default": "01v02.idr.out.bed",
                            "id": "#main/create_bed_from_idr/outputFilename"
                        }
                    ],
                    "out": [
                        "#main/create_bed_from_idr/output"
                    ],
                    "id": "#main/create_bed_from_idr"
                },
                {
                    "run": "#get_reproducing_peaks.cwl",
                    "in": [
                        {
                            "source": "#main/idr/output",
                            "id": "#main/get_reproducing_peaks/idr_file"
                        },
                        {
                            "source": "#main/merged_peaks_bed",
                            "id": "#main/get_reproducing_peaks/output_bed"
                        },
                        {
                            "source": "#main/merged_peaks_custombed",
                            "id": "#main/get_reproducing_peaks/output_custombed"
                        },
                        {
                            "source": "#main/rep1_input_norm_and_entropy/entropy_full",
                            "id": "#main/get_reproducing_peaks/rep1_entropy_file"
                        },
                        {
                            "source": "#main/rep1_input_norm_using_idr_peaks/inputNormedBedFull",
                            "id": "#main/get_reproducing_peaks/rep1_full_in"
                        },
                        {
                            "default": "01v02.IDR.out.0102merged.01.full",
                            "id": "#main/get_reproducing_peaks/rep1_full_output"
                        },
                        {
                            "source": "#main/rep2_input_norm_and_entropy/entropy_full",
                            "id": "#main/get_reproducing_peaks/rep2_entropy_file"
                        },
                        {
                            "source": "#main/rep2_input_norm_using_idr_peaks/inputNormedBedFull",
                            "id": "#main/get_reproducing_peaks/rep2_full_in"
                        },
                        {
                            "default": "01v02.IDR.out.0102merged.02.full",
                            "id": "#main/get_reproducing_peaks/rep2_full_output"
                        }
                    ],
                    "out": [
                        "#main/get_reproducing_peaks/rep1_full_output_file",
                        "#main/get_reproducing_peaks/rep2_full_output_file",
                        "#main/get_reproducing_peaks/output_bed_file",
                        "#main/get_reproducing_peaks/output_custombed_file"
                    ],
                    "id": "#main/get_reproducing_peaks"
                },
                {
                    "run": "#idr.cwl",
                    "in": [
                        {
                            "default": "bed",
                            "id": "#main/idr/inputFileType"
                        },
                        {
                            "default": "01v02.idr.out",
                            "id": "#main/idr/outputFilename"
                        },
                        {
                            "default": "max",
                            "id": "#main/idr/peakMergeMethod"
                        },
                        {
                            "default": true,
                            "id": "#main/idr/plot"
                        },
                        {
                            "default": 5,
                            "id": "#main/idr/rank"
                        },
                        {
                            "source": [
                                "#main/rep1_input_norm_and_entropy/entropy_bed",
                                "#main/rep2_input_norm_and_entropy/entropy_bed"
                            ],
                            "id": "#main/idr/samples"
                        }
                    ],
                    "out": [
                        "#main/idr/output"
                    ],
                    "id": "#main/idr"
                },
                {
                    "run": "#wf_input_norm_and_entropy.cwl",
                    "in": [
                        {
                            "source": "#main/rep1_clip_bam_file",
                            "id": "#main/rep1_input_norm_and_entropy/clip_bam_file"
                        },
                        {
                            "source": "#main/rep1_input_bam_file",
                            "id": "#main/rep1_input_norm_and_entropy/input_bam_file"
                        },
                        {
                            "source": "#main/rep1_peaks_bed_file",
                            "id": "#main/rep1_input_norm_and_entropy/peak_file"
                        }
                    ],
                    "out": [
                        "#main/rep1_input_norm_and_entropy/clip_read_num",
                        "#main/rep1_input_norm_and_entropy/input_read_num",
                        "#main/rep1_input_norm_and_entropy/input_normed_bed",
                        "#main/rep1_input_norm_and_entropy/input_normed_full",
                        "#main/rep1_input_norm_and_entropy/compressed_bed",
                        "#main/rep1_input_norm_and_entropy/compressed_full",
                        "#main/rep1_input_norm_and_entropy/entropy_full",
                        "#main/rep1_input_norm_and_entropy/entropy_excess_reads",
                        "#main/rep1_input_norm_and_entropy/entropy_bed"
                    ],
                    "id": "#main/rep1_input_norm_and_entropy"
                },
                {
                    "run": "#overlap_peakfi_with_bam.cwl",
                    "in": [
                        {
                            "source": "#main/rep1_clip_bam_file",
                            "id": "#main/rep1_input_norm_using_idr_peaks/clipBamFile"
                        },
                        {
                            "source": "#main/rep1_input_norm_and_entropy/clip_read_num",
                            "id": "#main/rep1_input_norm_using_idr_peaks/clipReadnum"
                        },
                        {
                            "source": "#main/rep1_input_bam_file",
                            "id": "#main/rep1_input_norm_using_idr_peaks/inputBamFile"
                        },
                        {
                            "source": "#main/rep1_input_norm_and_entropy/input_read_num",
                            "id": "#main/rep1_input_norm_using_idr_peaks/inputReadnum"
                        },
                        {
                            "source": "#main/create_bed_from_idr/output",
                            "id": "#main/rep1_input_norm_using_idr_peaks/peakFile"
                        }
                    ],
                    "out": [
                        "#main/rep1_input_norm_using_idr_peaks/inputNormedBed",
                        "#main/rep1_input_norm_using_idr_peaks/inputNormedBedFull"
                    ],
                    "id": "#main/rep1_input_norm_using_idr_peaks"
                },
                {
                    "run": "#wf_input_norm_and_entropy.cwl",
                    "in": [
                        {
                            "source": "#main/rep2_clip_bam_file",
                            "id": "#main/rep2_input_norm_and_entropy/clip_bam_file"
                        },
                        {
                            "source": "#main/rep2_input_bam_file",
                            "id": "#main/rep2_input_norm_and_entropy/input_bam_file"
                        },
                        {
                            "source": "#main/rep2_peaks_bed_file",
                            "id": "#main/rep2_input_norm_and_entropy/peak_file"
                        }
                    ],
                    "out": [
                        "#main/rep2_input_norm_and_entropy/clip_read_num",
                        "#main/rep2_input_norm_and_entropy/input_read_num",
                        "#main/rep2_input_norm_and_entropy/input_normed_bed",
                        "#main/rep2_input_norm_and_entropy/input_normed_full",
                        "#main/rep2_input_norm_and_entropy/compressed_bed",
                        "#main/rep2_input_norm_and_entropy/compressed_full",
                        "#main/rep2_input_norm_and_entropy/entropy_full",
                        "#main/rep2_input_norm_and_entropy/entropy_excess_reads",
                        "#main/rep2_input_norm_and_entropy/entropy_bed"
                    ],
                    "id": "#main/rep2_input_norm_and_entropy"
                },
                {
                    "run": "#overlap_peakfi_with_bam.cwl",
                    "in": [
                        {
                            "source": "#main/rep2_clip_bam_file",
                            "id": "#main/rep2_input_norm_using_idr_peaks/clipBamFile"
                        },
                        {
                            "source": "#main/rep2_input_norm_and_entropy/clip_read_num",
                            "id": "#main/rep2_input_norm_using_idr_peaks/clipReadnum"
                        },
                        {
                            "source": "#main/rep2_input_bam_file",
                            "id": "#main/rep2_input_norm_using_idr_peaks/inputBamFile"
                        },
                        {
                            "source": "#main/rep2_input_norm_and_entropy/input_read_num",
                            "id": "#main/rep2_input_norm_using_idr_peaks/inputReadnum"
                        },
                        {
                            "source": "#main/create_bed_from_idr/output",
                            "id": "#main/rep2_input_norm_using_idr_peaks/peakFile"
                        }
                    ],
                    "out": [
                        "#main/rep2_input_norm_using_idr_peaks/inputNormedBed",
                        "#main/rep2_input_norm_using_idr_peaks/inputNormedBedFull"
                    ],
                    "id": "#main/rep2_input_norm_using_idr_peaks"
                },
                {
                    "run": "#file2int.cwl",
                    "in": [
                        {
                            "source": "#main/count_reproducing_peaks/linescount",
                            "id": "#main/reproducible_peaks_file_to_int/file"
                        }
                    ],
                    "out": [
                        "#main/reproducible_peaks_file_to_int/output"
                    ],
                    "id": "#main/reproducible_peaks_file_to_int"
                }
            ],
            "id": "#main"
        },
        {
            "doc": "This workflow normalizes clip aligned reads against a size-matched input\nsample. Then, an entropy score is calculated for each peak found.\n",
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#wf_input_norm_and_entropy.cwl/clip_bam_file"
                },
                {
                    "type": "File",
                    "id": "#wf_input_norm_and_entropy.cwl/input_bam_file"
                },
                {
                    "type": "File",
                    "id": "#wf_input_norm_and_entropy.cwl/peak_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/readnum",
                    "id": "#wf_input_norm_and_entropy.cwl/clip_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/compress_peaks/output_bed",
                    "id": "#wf_input_norm_and_entropy.cwl/compressed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/compress_peaks/output_full",
                    "id": "#wf_input_norm_and_entropy.cwl/compressed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/create_entropybed_from_entropyfull/bed",
                    "id": "#wf_input_norm_and_entropy.cwl/entropy_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_excess_reads",
                    "id": "#wf_input_norm_and_entropy.cwl/entropy_excess_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_full",
                    "id": "#wf_input_norm_and_entropy.cwl/entropy_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/input_norm/inputNormedBed",
                    "id": "#wf_input_norm_and_entropy.cwl/input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/input_norm/inputNormedBedFull",
                    "id": "#wf_input_norm_and_entropy.cwl/input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/readnum",
                    "id": "#wf_input_norm_and_entropy.cwl/input_read_num"
                }
            ],
            "steps": [
                {
                    "run": "#calculate_readnum.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/clip_bam_file",
                            "id": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/bamFile"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/readnum"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum"
                },
                {
                    "run": "#calculate_readnum.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/input_bam_file",
                            "id": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/bamFile"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/readnum"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum"
                },
                {
                    "run": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/input_norm/inputNormedBedFull",
                            "id": "#wf_input_norm_and_entropy.cwl/compress_peaks/input_full"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/compress_peaks/output_bed",
                        "#wf_input_norm_and_entropy.cwl/compress_peaks/output_full"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/compress_peaks"
                },
                {
                    "run": "#full_to_bed.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_full",
                            "id": "#wf_input_norm_and_entropy.cwl/create_entropybed_from_entropyfull/full"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/create_entropybed_from_entropyfull/bed"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/create_entropybed_from_entropyfull"
                },
                {
                    "run": "#overlap_peakfi_with_bam.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/clip_bam_file",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/clipBamFile"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/readnum",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/clipReadnum"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/input_bam_file",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/inputBamFile"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/readnum",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/inputReadnum"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/peak_file",
                            "id": "#wf_input_norm_and_entropy.cwl/input_norm/peakFile"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/input_norm/inputNormedBed",
                        "#wf_input_norm_and_entropy.cwl/input_norm/inputNormedBedFull"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/input_norm"
                },
                {
                    "run": "#make_informationcontent_from_peaks.cwl",
                    "in": [
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/calculate_clip_readnum/readnum",
                            "id": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/clip_read_num"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/compress_peaks/output_full",
                            "id": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/compressed_bed_full"
                        },
                        {
                            "source": "#wf_input_norm_and_entropy.cwl/calculate_input_readnum/readnum",
                            "id": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/input_read_num"
                        }
                    ],
                    "out": [
                        "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_full",
                        "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks/entropy_excess_reads"
                    ],
                    "id": "#wf_input_norm_and_entropy.cwl/make_informationcontent_from_peaks"
                }
            ],
            "id": "#wf_input_norm_and_entropy.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
